==> strplus-1.0.2.tar.gz: strplus-1.0.2/README.md <==
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="Wise Up Data's Instagram" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/instagram.png" />   
</a> 
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="wise Up Data's Discord" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/discord.png" />
</a>
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="wise Up Data | Twitter" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/twitter.png" />
</a>
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="wise Up Data's LinkedIN" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/linkedin.png" />
</a>

![visitors](https://visitor-badge.glitch.me/badge?page_id=wiseupdata.strplus&left_color=green&right_color=black)
![license](https://img.shields.io/github/license/wiseupdata/strplus)
[![pypi](https://img.shields.io/pypi/v/strplus?color=green)](https://pypi.python.org/pypi/strplus)
[![downloads](https://pepy.tech/badge/strplus/month)](https://pepy.tech/project/strplus)
[![versions](https://img.shields.io/pypi/pyversions/strplus.svg)](https://github.com/wiseupdata/strplus)



---

<br>
<br>

<a href="https://github.com/wiseupdata/wiseupdata">
<img align="left" alt="img" src="https://raw.githubusercontent.com/wiseupdata/strplus/main/assets/python.png" width="300" />
</a>

<h1>
Python extra functions for strings ❤️
</h1>

<br>
<br>
<br>
<br>
<br>
<br>

[Documentation](https://wiseupdata.github.io/strplus/index.html)  🚀

<br>

## Features ✨️

- Wrapper Class
- +234 test in 32 Tests files!
- Simple use! 

<br>

### Simple use example 😍
```
>>> my_string = Str('Cast_this_string_TO_Pascal')
>>> my_string.pascal
'CastThisStringToPascal'

>>> my_string = Str('CastMeUseLikeANormalFunction')
>>> my_string.snake
'cast_me_use_like_a_normal_function'

```
<br>

* [More Examples !](https://github.com/wiseupdata/strplus/blob/main/examples/examples_01.ipynb)
* [Documentations examples](https://wiseupdata.github.io/strplus/index.html)! 

<br>
<br>

# References 🌍 🗄️

1. [Wise Up Data](https://github.com/wiseupdata)
2. [Emojis](https://github.com/wiseupdata/emojis)
3. [Pypi Deploy](https://www.digitalocean.com/community/tutorials/how-to-publish-python-packages-to-pypi-using-poetry-on-ubuntu-22-04)

<br>
<br>
---

#### Maintainer 🤗 👨‍💻

Sivio Liborio

📧 silvio.liborio@wiseupdata.com

<a href="https://www.linkedin.com/in/silvio-de-melo-liborio">silvio-de-melo-liborio <img align="left" alt="LinkedIN" width="18px" src="https://raw.githubusercontent.com/wiseupdata/wsl-latest/main/assets/linkedin.svg" />
</a>

<br>
<br>
<br>
<br>
<br>

> WiseUpData

==> strplus-1.0.3.tar.gz: strplus-1.0.3/README.md <==
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="Wise Up Data's Instagram" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/instagram.png" />   
</a> 
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="wise Up Data's Discord" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/discord.png" />
</a>
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="wise Up Data | Twitter" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/twitter.png" />
</a>
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="wise Up Data's LinkedIN" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/linkedin.png" />
</a>

![visitors](https://visitor-badge.glitch.me/badge?page_id=wiseupdata.strplus&left_color=green&right_color=black)
![license](https://img.shields.io/github/license/wiseupdata/strplus)
[![pypi](https://img.shields.io/pypi/v/strplus?color=green)](https://pypi.python.org/pypi/strplus)
[![downloads](https://pepy.tech/badge/strplus/month)](https://pepy.tech/project/strplus)
[![versions](https://img.shields.io/pypi/pyversions/strplus.svg)](https://github.com/wiseupdata/strplus)



---

<br>
<br>

<a href="https://github.com/wiseupdata/wiseupdata">
<img align="left" alt="img" src="https://raw.githubusercontent.com/wiseupdata/strplus/main/assets/imgs/python.png" width="300" />
</a>

<h1>
Python extra functions for strings ❤️
</h1>

<br>
<br>
<br>
<br>
<br>
<br>

[Documentation](https://wiseupdata.github.io/strplus/index.html)  🚀

<br>

## Features ✨️

- Wrapper Class
- +234 test in 32 Tests files!
- Simple use! 

<br>

### Simple use example 😍
```
>>> my_string = Str('Cast_this_string_TO_Pascal')
>>> my_string.pascal
'CastThisStringToPascal'

>>> my_string = Str('CastMeUseLikeANormalFunction')
>>> my_string.snake
'cast_me_use_like_a_normal_function'

```
<br>

* [More Examples !](https://github.com/wiseupdata/strplus/blob/main/examples/examples_01.ipynb)
* [Documentations examples](https://wiseupdata.github.io/strplus/index.html)! 

<br>
<br>

# References 🌍 🗄️

1. [Wise Up Data](https://github.com/wiseupdata)
2. [Emojis](https://github.com/wiseupdata/emojis)
3. [Pypi Deploy](https://www.digitalocean.com/community/tutorials/how-to-publish-python-packages-to-pypi-using-poetry-on-ubuntu-22-04)

<br>
<br>
---

#### Maintainer 🤗 👨‍💻

Sivio Liborio

📧 silvio.liborio@wiseupdata.com

<a href="https://www.linkedin.com/in/silvio-de-melo-liborio">silvio-de-melo-liborio <img align="left" alt="LinkedIN" width="18px" src="https://raw.githubusercontent.com/wiseupdata/wsl-latest/main/assets/linkedin.svg" />
</a>

<br>
<br>
<br>
<br>
<br>

> WiseUpData
